.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

Technical Steering Committee
----------------------------

The Technical Steering Committee (TSC) is responsible for:

1. General ambitions, objectives and goals of this project
2. Guidelines and procedures and tool selection
3. Architectural and (development) infrastructure choices
4. Raise subjects/issues that are important for the direction/development of this project

The TSC consists of the following members:

1. Jonas van den Bogaard
2. Frank Kreuwel
3. Jan Maarten van Doorn
4. Frederik Stoel
5. Daan van Es (chair)
6. Maxime Fortin
7. Bart Pleiter

Any community member or Contributor can ask that something be reviewed by the TSC by contacting the TSC at ``openstef@lfenergy.org``.

More information, meeting notes and meeting links can be found in the `TSC documentation <https://wiki.lfenergy.org/display/OS/OpenSTEF+Technical+Steering+Committee>`_.

More information on project governance can be found in the `project governance documentation <https://github.com/OpenSTEF/.github/blob/main/PROJECT_GOVERNANCE.md>`_.
